# The software in this package is distributed under the GNU General
# Public License version 2 (with a special exception described below).
#
# A copy of GNU General Public License (GPL) is included in this distribution,
# in the file COPYING.GPL.
#
# As a special exception, if other files instantiate templates or use macros
# or inline functions from this file, or you compile this file and link it
# with other works to produce a work based on this file, this file
# does not by itself cause the resulting work to be covered
# by the GNU General Public License.
#
# However the source code for this file must still be made available
# in accordance with section (3) of the GNU General Public License.
#
# This exception does not invalidate any other reasons why a work based
# on this file might be covered by the GNU General Public License.
#
# Copyright (c) 2016-2018 Intra2net AG <info@intra2net.com>

class CnfLine(object):
    """Represents an arnied cnfline"""

    def __init__(self,
                 name='',
                 instance=0,
                 data='',
                 line_no=1,
                 parent_line_no=0):
        self.name = name
        self.instance = instance
        self.data = data
        self.line_no = line_no
        self.parent_line_no = parent_line_no

        if len(self.name) == 0:
            raise ValueError("You can't leave the cnfvar name empty")

        if line_no == 0:
            raise ValueError('Zero is not a valid line number')

    def __str__(self):
        """Build cnfline string representation"""

        # Sanity checks
        if len(self.name) == 0:
            raise ValueError("Can't display empty cnfvar name")
        if self.line_no == 0:
            raise ValueError('Zero is not a valid line number')

        if self.parent_line_no:
            rtn = '{0} ({1})'.format(self.line_no, self.parent_line_no)
        else:
            rtn = '{0}'.format(self.line_no)

        rtn += ' {0},{1}: "{2}"'.format(self.name, self.instance, self.data)

        return rtn
